==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/FormsType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p251053_="https://jakarta.ee/xml/ns/jaxb" xmlns:p29516_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The forms operation element can be used to import and export PDF forms.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for FormsType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="FormsType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="import" type="{http://schema.webpdf.de/1.0/operation}FormsImportType" minOccurs="0"/>
 *         <element name="export" type="{http://schema.webpdf.de/1.0/operation}FormsExportType" minOccurs="0"/>
 *         <element name="flatten" type="{http://schema.webpdf.de/1.0/operation}FormsFlattenType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FormsType", propOrder = {
    "_import",
    "export",
    "flatten"
})
public class FormsType
    extends BaseToolboxType
{

    @XmlElement(name = "import")
    protected FormsImportType _import;
    protected FormsExportType export;
    protected FormsFlattenType flatten;

    /**
     * Gets the value of the import property.
     * 
     * @return
     *     possible object is
     *     {@link FormsImportType }
     *     
     */
    public FormsImportType getImport() {
        return _import;
    }

    /**
     * Sets the value of the import property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsImportType }
     *     
     */
    public void setImport(FormsImportType value) {
        this._import = value;
    }

    public boolean isSetImport() {
        return (this._import!= null);
    }

    /**
     * Gets the value of the export property.
     * 
     * @return
     *     possible object is
     *     {@link FormsExportType }
     *     
     */
    public FormsExportType getExport() {
        return export;
    }

    /**
     * Sets the value of the export property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsExportType }
     *     
     */
    public void setExport(FormsExportType value) {
        this.export = value;
    }

    public boolean isSetExport() {
        return (this.export!= null);
    }

    /**
     * Gets the value of the flatten property.
     * 
     * @return
     *     possible object is
     *     {@link FormsFlattenType }
     *     
     */
    public FormsFlattenType getFlatten() {
        return flatten;
    }

    /**
     * Sets the value of the flatten property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsFlattenType }
     *     
     */
    public void setFlatten(FormsFlattenType value) {
        this.flatten = value;
    }

    public boolean isSetFlatten() {
        return (this.flatten!= null);
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/FormsType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p681724_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p991286_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The forms operation element can be used to import and export PDF forms.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for FormsType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="FormsType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="import" type="{http://schema.webpdf.de/1.0/operation}FormsImportType" minOccurs="0"/>
 *         <element name="export" type="{http://schema.webpdf.de/1.0/operation}FormsExportType" minOccurs="0"/>
 *         <element name="flatten" type="{http://schema.webpdf.de/1.0/operation}FormsFlattenType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FormsType", propOrder = {
    "_import",
    "export",
    "flatten"
})
public class FormsType
    extends BaseToolboxType
{

    @XmlElement(name = "import")
    protected FormsImportType _import;
    protected FormsExportType export;
    protected FormsFlattenType flatten;

    /**
     * Gets the value of the import property.
     * 
     * @return
     *     possible object is
     *     {@link FormsImportType }
     *     
     */
    public FormsImportType getImport() {
        return _import;
    }

    /**
     * Sets the value of the import property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsImportType }
     *     
     */
    public void setImport(FormsImportType value) {
        this._import = value;
    }

    public boolean isSetImport() {
        return (this._import!= null);
    }

    /**
     * Gets the value of the export property.
     * 
     * @return
     *     possible object is
     *     {@link FormsExportType }
     *     
     */
    public FormsExportType getExport() {
        return export;
    }

    /**
     * Sets the value of the export property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsExportType }
     *     
     */
    public void setExport(FormsExportType value) {
        this.export = value;
    }

    public boolean isSetExport() {
        return (this.export!= null);
    }

    /**
     * Gets the value of the flatten property.
     * 
     * @return
     *     possible object is
     *     {@link FormsFlattenType }
     *     
     */
    public FormsFlattenType getFlatten() {
        return flatten;
    }

    /**
     * Sets the value of the flatten property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsFlattenType }
     *     
     */
    public void setFlatten(FormsFlattenType value) {
        this.flatten = value;
    }

    public boolean isSetFlatten() {
        return (this.flatten!= null);
    }

}
